@@ -484,6 +484,10 @@ MainWindow::initQML ()
                   &oInbox,   SLOT(refresh()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL(sigHaptic()),
+                  this, SLOT(onBtnClickFroHapticFeedback()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
 
     gObj = getQMLObject ("RegisteredPhonesView");
     if (NULL == gObj) {
@@ -577,7 +581,7 @@ MainWindow::connectSettingsSignals()
         Q_ASSERT(rv);
         if (!rv) { break; }
         rv = connect (
-                    obj , SIGNAL(sigPinSettingChanges  (bool, const QString &)),
+                    obj , SIGNAL(sigPinSettingChanges (bool, const QString &)),
                     this, SLOT (onSigPinSettingChanges(bool, const QString &)));
         Q_ASSERT(rv);
         if (!rv) { break; }
@@ -1254,3 +1258,10 @@ MainWindow::ensureNwMgr()
 
     return (nwMgr != NULL);
 }//MainWindow::ensureNwMgr
+
+void
+MainWindow::onBtnClickFroHapticFeedback()
+{
+    OsDependent &osd = Singletons::getRef().getOSD ();
+    osd.onBtnClickFroHapticFeedback ();
+}//MainWindow::onBtnClickFroHapticFeedback
