@@ -205,6 +205,9 @@ private slots:
     void onLogPosted(bool success, const QByteArray &response,
                      QNetworkReply *reply, void *ctx);
 
+    //! Invoked when ANY button is clicked and requires a haptic feedback
+    void onBtnClickFroHapticFeedback();
+
 private:
     void initLogging ();
 
